@@ -125,6 +125,63 @@ gboolean tp_cli_channel_interface_call_state_run_get_call_states (TpChannel *pro
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_captcha_authentication_callback_for_get_captchas) (TpChannel *proxy,
+    const GPtrArray *out_Captcha_Info,
+    guint out_Number_Required,
+    const gchar *out_Language,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_captcha_authentication_call_get_captchas (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_interface_captcha_authentication_callback_for_get_captchas callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_interface_captcha_authentication_callback_for_get_captcha_data) (TpChannel *proxy,
+    const GArray *out_Captcha_Data,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_captcha_authentication_call_get_captcha_data (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_ID,
+    const gchar *in_Mime_Type,
+    tp_cli_channel_interface_captcha_authentication_callback_for_get_captcha_data callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_interface_captcha_authentication_callback_for_answer_captchas) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_captcha_authentication_call_answer_captchas (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_Answers,
+    tp_cli_channel_interface_captcha_authentication_callback_for_answer_captchas callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_interface_captcha_authentication_callback_for_cancel_captcha) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_captcha_authentication_call_cancel_captcha (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Reason,
+    const gchar *in_Debug_Message,
+    tp_cli_channel_interface_captcha_authentication_callback_for_cancel_captcha callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_channel_interface_chat_state_signal_callback_chat_state_changed) (TpChannel *proxy,
     guint arg_Contact,
     guint arg_State,
@@ -1060,6 +1117,120 @@ TpProxySignalConnection *tp_cli_channel_interface_tube_connect_to_tube_channel_s
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_type_call_signal_callback_content_added) (TpChannel *proxy,
+    const gchar *arg_Content,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_call_connect_to_content_added (TpChannel *proxy,
+    tp_cli_channel_type_call_signal_callback_content_added callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_call_signal_callback_content_removed) (TpChannel *proxy,
+    const gchar *arg_Content,
+    const GValueArray *arg_Reason,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_call_connect_to_content_removed (TpChannel *proxy,
+    tp_cli_channel_type_call_signal_callback_content_removed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_call_signal_callback_call_state_changed) (TpChannel *proxy,
+    guint arg_Call_State,
+    guint arg_Call_Flags,
+    const GValueArray *arg_Call_State_Reason,
+    GHashTable *arg_Call_State_Details,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_call_connect_to_call_state_changed (TpChannel *proxy,
+    tp_cli_channel_type_call_signal_callback_call_state_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_call_signal_callback_call_members_changed) (TpChannel *proxy,
+    GHashTable *arg_Flags_Changed,
+    GHashTable *arg_Identifiers,
+    const GArray *arg_Removed,
+    const GValueArray *arg_Reason,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_call_connect_to_call_members_changed (TpChannel *proxy,
+    tp_cli_channel_type_call_signal_callback_call_members_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_call_callback_for_set_ringing) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_call_call_set_ringing (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_type_call_callback_for_set_ringing callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_type_call_callback_for_set_queued) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_call_call_set_queued (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_type_call_callback_for_set_queued callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_type_call_callback_for_accept) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_call_call_accept (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_type_call_callback_for_accept callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_type_call_callback_for_hangup) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_call_call_hangup (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Reason,
+    const gchar *in_Detailed_Hangup_Reason,
+    const gchar *in_Message,
+    tp_cli_channel_type_call_callback_for_hangup callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_channel_type_call_callback_for_add_content) (TpChannel *proxy,
+    const gchar *out_Content,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_call_call_add_content (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Content_Name,
+    guint in_Content_Type,
+    guint in_InitialDirection,
+    tp_cli_channel_type_call_callback_for_add_content callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_channel_type_contact_search_signal_callback_search_state_changed) (TpChannel *proxy,
     guint arg_State,
     const gchar *arg_Error,
