@@ -356,6 +356,39 @@ gboolean tp_cli_connection_run_remove_client_interest (TpConnection *proxy,
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_addressing_callback_for_get_contacts_by_vcard_field) (TpConnection *proxy,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_addressing_call_get_contacts_by_vcard_field (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Field,
+    const gchar **in_Addresses,
+    const gchar **in_Interfaces,
+    tp_cli_connection_interface_addressing_callback_for_get_contacts_by_vcard_field callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
+typedef void (*tp_cli_connection_interface_addressing_callback_for_get_contacts_by_uri) (TpConnection *proxy,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_addressing_call_get_contacts_by_uri (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar **in_URIs,
+    const gchar **in_Interfaces,
+    tp_cli_connection_interface_addressing_callback_for_get_contacts_by_uri callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_connection_interface_aliasing_signal_callback_aliases_changed) (TpConnection *proxy,
     const GPtrArray *arg_Aliases,
     gpointer user_data, GObject *weak_object);
@@ -1363,6 +1396,18 @@ gboolean tp_cli_connection_interface_contact_list_run_unpublish (TpConnection *p
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_contact_list_callback_for_download) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_list_call_download (TpConnection *proxy,
+    gint timeout_ms,
+    tp_cli_connection_interface_contact_list_callback_for_download callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_connection_interface_contacts_callback_for_get_contact_attributes) (TpConnection *proxy,
     GHashTable *out_Attributes,
     const GError *error, gpointer user_data,
