@@ -91,6 +91,27 @@ TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_start_telephony_
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_media_stream_handler_signal_callback_start_named_telephony_event) (TpMediaStreamHandler *proxy,
+    guchar arg_Event,
+    guint arg_Codec_ID,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_start_named_telephony_event (TpMediaStreamHandler *proxy,
+    tp_cli_media_stream_handler_signal_callback_start_named_telephony_event callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_media_stream_handler_signal_callback_start_sound_telephony_event) (TpMediaStreamHandler *proxy,
+    guchar arg_Event,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_start_sound_telephony_event (TpMediaStreamHandler *proxy,
+    tp_cli_media_stream_handler_signal_callback_start_sound_telephony_event callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_media_stream_handler_signal_callback_stop_telephony_event) (TpMediaStreamHandler *proxy,
     gpointer user_data, GObject *weak_object);
 TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_stop_telephony_event (TpMediaStreamHandler *proxy,
@@ -110,6 +131,26 @@ TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_set_stream_held
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_media_stream_handler_signal_callback_set_remote_feedback_messages) (TpMediaStreamHandler *proxy,
+    GHashTable *arg_Messages,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_set_remote_feedback_messages (TpMediaStreamHandler *proxy,
+    tp_cli_media_stream_handler_signal_callback_set_remote_feedback_messages callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_media_stream_handler_signal_callback_set_remote_header_extensions) (TpMediaStreamHandler *proxy,
+    const GPtrArray *arg_Header_Extensions,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_media_stream_handler_connect_to_set_remote_header_extensions (TpMediaStreamHandler *proxy,
+    tp_cli_media_stream_handler_signal_callback_set_remote_header_extensions callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_media_stream_handler_callback_for_codec_choice) (TpMediaStreamHandler *proxy,
     const GError *error, gpointer user_data,
     GObject *weak_object);
@@ -196,6 +237,33 @@ gboolean tp_cli_media_stream_handler_run_new_active_candidate_pair (TpMediaStrea
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_media_stream_handler_callback_for_new_active_transport_pair) (TpMediaStreamHandler *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_media_stream_handler_call_new_active_transport_pair (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    const gchar *in_Native_Candidate_ID,
+    const GValueArray *in_Native_Transport,
+    const gchar *in_Remote_Candidate_ID,
+    const GValueArray *in_Remote_Transport,
+    tp_cli_media_stream_handler_callback_for_new_active_transport_pair callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_media_stream_handler_run_new_active_transport_pair (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    const gchar *in_Native_Candidate_ID,
+    const GValueArray *in_Native_Transport,
+    const gchar *in_Remote_Candidate_ID,
+    const GValueArray *in_Remote_Transport,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_media_stream_handler_callback_for_new_native_candidate) (TpMediaStreamHandler *proxy,
     const GError *error, gpointer user_data,
     GObject *weak_object);
@@ -364,4 +432,46 @@ gboolean tp_cli_media_stream_handler_run_unhold_failure (TpMediaStreamHandler *p
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_media_stream_handler_callback_for_supported_feedback_messages) (TpMediaStreamHandler *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_media_stream_handler_call_supported_feedback_messages (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    GHashTable *in_Messages,
+    tp_cli_media_stream_handler_callback_for_supported_feedback_messages callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_media_stream_handler_run_supported_feedback_messages (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    GHashTable *in_Messages,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_media_stream_handler_callback_for_supported_header_extensions) (TpMediaStreamHandler *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_media_stream_handler_call_supported_header_extensions (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Header_Extensions,
+    tp_cli_media_stream_handler_callback_for_supported_header_extensions callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_media_stream_handler_run_supported_header_extensions (TpMediaStreamHandler *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Header_Extensions,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 G_END_DECLS
