@@ -64,6 +64,36 @@ void tp_svc_account_emit_removed (gpointer instance);
 void tp_svc_account_emit_account_property_changed (gpointer instance,
     GHashTable *arg_Properties);
 
+typedef struct _TpSvcAccountInterfaceAddressing TpSvcAccountInterfaceAddressing;
+
+typedef struct _TpSvcAccountInterfaceAddressingClass TpSvcAccountInterfaceAddressingClass;
+
+GType tp_svc_account_interface_addressing_get_type (void);
+#define TP_TYPE_SVC_ACCOUNT_INTERFACE_ADDRESSING \
+  (tp_svc_account_interface_addressing_get_type ())
+#define TP_SVC_ACCOUNT_INTERFACE_ADDRESSING(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_ACCOUNT_INTERFACE_ADDRESSING, TpSvcAccountInterfaceAddressing))
+#define TP_IS_SVC_ACCOUNT_INTERFACE_ADDRESSING(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_ACCOUNT_INTERFACE_ADDRESSING))
+#define TP_SVC_ACCOUNT_INTERFACE_ADDRESSING_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_ACCOUNT_INTERFACE_ADDRESSING, TpSvcAccountInterfaceAddressingClass))
+
+
+typedef void (*tp_svc_account_interface_addressing_set_uri_scheme_association_impl) (TpSvcAccountInterfaceAddressing *self,
+    const gchar *in_URI_Scheme,
+    gboolean in_Association,
+    DBusGMethodInvocation *context);
+void tp_svc_account_interface_addressing_implement_set_uri_scheme_association (TpSvcAccountInterfaceAddressingClass *klass, tp_svc_account_interface_addressing_set_uri_scheme_association_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_account_interface_addressing_return_from_set_uri_scheme_association (DBusGMethodInvocation *context);
+static inline void
+tp_svc_account_interface_addressing_return_from_set_uri_scheme_association (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+
 typedef struct _TpSvcAccountInterfaceAvatar TpSvcAccountInterfaceAvatar;
 
 typedef struct _TpSvcAccountInterfaceAvatarClass TpSvcAccountInterfaceAvatarClass;
