@@ -47,6 +47,11 @@ void tp_svc_channel_request_emit_failed (gpointer instance,
     const gchar *arg_Error,
     const gchar *arg_Message);
 void tp_svc_channel_request_emit_succeeded (gpointer instance);
+void tp_svc_channel_request_emit_succeeded_with_channel (gpointer instance,
+    const gchar *arg_Connection,
+    GHashTable *arg_Connection_Properties,
+    const gchar *arg_Channel,
+    GHashTable *arg_Channel_Properties);
 
 
 G_END_DECLS
