@@ -131,6 +131,87 @@ void tp_svc_channel_interface_call_state_emit_call_state_changed (gpointer insta
     guint arg_Contact,
     guint arg_State);
 
+typedef struct _TpSvcChannelInterfaceCaptchaAuthentication TpSvcChannelInterfaceCaptchaAuthentication;
+
+typedef struct _TpSvcChannelInterfaceCaptchaAuthenticationClass TpSvcChannelInterfaceCaptchaAuthenticationClass;
+
+GType tp_svc_channel_interface_captcha_authentication_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION \
+  (tp_svc_channel_interface_captcha_authentication_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION, TpSvcChannelInterfaceCaptchaAuthentication))
+#define TP_IS_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION))
+#define TP_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_CAPTCHA_AUTHENTICATION, TpSvcChannelInterfaceCaptchaAuthenticationClass))
+
+
+typedef void (*tp_svc_channel_interface_captcha_authentication_get_captchas_impl) (TpSvcChannelInterfaceCaptchaAuthentication *self,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_captcha_authentication_implement_get_captchas (TpSvcChannelInterfaceCaptchaAuthenticationClass *klass, tp_svc_channel_interface_captcha_authentication_get_captchas_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_captcha_authentication_return_from_get_captchas (DBusGMethodInvocation *context,
+    const GPtrArray *out_Captcha_Info,
+    guint out_Number_Required,
+    const gchar *out_Language);
+static inline void
+tp_svc_channel_interface_captcha_authentication_return_from_get_captchas (DBusGMethodInvocation *context,
+    const GPtrArray *out_Captcha_Info,
+    guint out_Number_Required,
+    const gchar *out_Language)
+{
+  dbus_g_method_return (context,
+      out_Captcha_Info,
+      out_Number_Required,
+      out_Language);
+}
+
+typedef void (*tp_svc_channel_interface_captcha_authentication_get_captcha_data_impl) (TpSvcChannelInterfaceCaptchaAuthentication *self,
+    guint in_ID,
+    const gchar *in_Mime_Type,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_captcha_authentication_implement_get_captcha_data (TpSvcChannelInterfaceCaptchaAuthenticationClass *klass, tp_svc_channel_interface_captcha_authentication_get_captcha_data_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_captcha_authentication_return_from_get_captcha_data (DBusGMethodInvocation *context,
+    const GArray *out_Captcha_Data);
+static inline void
+tp_svc_channel_interface_captcha_authentication_return_from_get_captcha_data (DBusGMethodInvocation *context,
+    const GArray *out_Captcha_Data)
+{
+  dbus_g_method_return (context,
+      out_Captcha_Data);
+}
+
+typedef void (*tp_svc_channel_interface_captcha_authentication_answer_captchas_impl) (TpSvcChannelInterfaceCaptchaAuthentication *self,
+    GHashTable *in_Answers,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_captcha_authentication_implement_answer_captchas (TpSvcChannelInterfaceCaptchaAuthenticationClass *klass, tp_svc_channel_interface_captcha_authentication_answer_captchas_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_captcha_authentication_return_from_answer_captchas (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_captcha_authentication_return_from_answer_captchas (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_interface_captcha_authentication_cancel_captcha_impl) (TpSvcChannelInterfaceCaptchaAuthentication *self,
+    guint in_Reason,
+    const gchar *in_Debug_Message,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_captcha_authentication_implement_cancel_captcha (TpSvcChannelInterfaceCaptchaAuthenticationClass *klass, tp_svc_channel_interface_captcha_authentication_cancel_captcha_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_captcha_authentication_return_from_cancel_captcha (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_captcha_authentication_return_from_cancel_captcha (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+
 typedef struct _TpSvcChannelInterfaceChatState TpSvcChannelInterfaceChatState;
 
 typedef struct _TpSvcChannelInterfaceChatStateClass TpSvcChannelInterfaceChatStateClass;
@@ -276,6 +357,22 @@ tp_svc_channel_interface_destroyable_return_from_destroy (DBusGMethodInvocation
 }
 
 
+typedef struct _TpSvcChannelInterfaceFileTransferMetadata TpSvcChannelInterfaceFileTransferMetadata;
+
+typedef struct _TpSvcChannelInterfaceFileTransferMetadataClass TpSvcChannelInterfaceFileTransferMetadataClass;
+
+GType tp_svc_channel_interface_file_transfer_metadata_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA \
+  (tp_svc_channel_interface_file_transfer_metadata_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA, TpSvcChannelInterfaceFileTransferMetadata))
+#define TP_IS_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA))
+#define TP_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_FILE_TRANSFER_METADATA, TpSvcChannelInterfaceFileTransferMetadataClass))
+
+
+
 typedef struct _TpSvcChannelInterfaceGroup TpSvcChannelInterfaceGroup;
 
 typedef struct _TpSvcChannelInterfaceGroupClass TpSvcChannelInterfaceGroupClass;
@@ -937,6 +1034,106 @@ GType tp_svc_channel_interface_tube_get_type (void);
 void tp_svc_channel_interface_tube_emit_tube_channel_state_changed (gpointer instance,
     guint arg_State);
 
+typedef struct _TpSvcChannelTypeCall TpSvcChannelTypeCall;
+
+typedef struct _TpSvcChannelTypeCallClass TpSvcChannelTypeCallClass;
+
+GType tp_svc_channel_type_call_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_TYPE_CALL \
+  (tp_svc_channel_type_call_get_type ())
+#define TP_SVC_CHANNEL_TYPE_CALL(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_TYPE_CALL, TpSvcChannelTypeCall))
+#define TP_IS_SVC_CHANNEL_TYPE_CALL(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_TYPE_CALL))
+#define TP_SVC_CHANNEL_TYPE_CALL_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_TYPE_CALL, TpSvcChannelTypeCallClass))
+
+
+typedef void (*tp_svc_channel_type_call_set_ringing_impl) (TpSvcChannelTypeCall *self,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_type_call_implement_set_ringing (TpSvcChannelTypeCallClass *klass, tp_svc_channel_type_call_set_ringing_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_type_call_return_from_set_ringing (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_type_call_return_from_set_ringing (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_type_call_set_queued_impl) (TpSvcChannelTypeCall *self,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_type_call_implement_set_queued (TpSvcChannelTypeCallClass *klass, tp_svc_channel_type_call_set_queued_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_type_call_return_from_set_queued (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_type_call_return_from_set_queued (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_type_call_accept_impl) (TpSvcChannelTypeCall *self,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_type_call_implement_accept (TpSvcChannelTypeCallClass *klass, tp_svc_channel_type_call_accept_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_type_call_return_from_accept (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_type_call_return_from_accept (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_type_call_hangup_impl) (TpSvcChannelTypeCall *self,
+    guint in_Reason,
+    const gchar *in_Detailed_Hangup_Reason,
+    const gchar *in_Message,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_type_call_implement_hangup (TpSvcChannelTypeCallClass *klass, tp_svc_channel_type_call_hangup_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_type_call_return_from_hangup (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_type_call_return_from_hangup (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_type_call_add_content_impl) (TpSvcChannelTypeCall *self,
+    const gchar *in_Content_Name,
+    guint in_Content_Type,
+    guint in_InitialDirection,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_type_call_implement_add_content (TpSvcChannelTypeCallClass *klass, tp_svc_channel_type_call_add_content_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_type_call_return_from_add_content (DBusGMethodInvocation *context,
+    const gchar *out_Content);
+static inline void
+tp_svc_channel_type_call_return_from_add_content (DBusGMethodInvocation *context,
+    const gchar *out_Content)
+{
+  dbus_g_method_return (context,
+      out_Content);
+}
+
+void tp_svc_channel_type_call_emit_content_added (gpointer instance,
+    const gchar *arg_Content);
+void tp_svc_channel_type_call_emit_content_removed (gpointer instance,
+    const gchar *arg_Content,
+    const GValueArray *arg_Reason);
+void tp_svc_channel_type_call_emit_call_state_changed (gpointer instance,
+    guint arg_Call_State,
+    guint arg_Call_Flags,
+    const GValueArray *arg_Call_State_Reason,
+    GHashTable *arg_Call_State_Details);
+void tp_svc_channel_type_call_emit_call_members_changed (gpointer instance,
+    GHashTable *arg_Flags_Changed,
+    GHashTable *arg_Identifiers,
+    const GArray *arg_Removed,
+    const GValueArray *arg_Reason);
+
 typedef struct _TpSvcChannelTypeContactList TpSvcChannelTypeContactList;
 
 typedef struct _TpSvcChannelTypeContactListClass TpSvcChannelTypeContactListClass;
