@@ -240,6 +240,63 @@ void tp_svc_connection_emit_status_changed (gpointer instance,
     guint arg_Status,
     guint arg_Reason);
 
+typedef struct _TpSvcConnectionInterfaceAddressing TpSvcConnectionInterfaceAddressing;
+
+typedef struct _TpSvcConnectionInterfaceAddressingClass TpSvcConnectionInterfaceAddressingClass;
+
+GType tp_svc_connection_interface_addressing_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_ADDRESSING \
+  (tp_svc_connection_interface_addressing_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_ADDRESSING(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_ADDRESSING, TpSvcConnectionInterfaceAddressing))
+#define TP_IS_SVC_CONNECTION_INTERFACE_ADDRESSING(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_ADDRESSING))
+#define TP_SVC_CONNECTION_INTERFACE_ADDRESSING_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_ADDRESSING, TpSvcConnectionInterfaceAddressingClass))
+
+
+typedef void (*tp_svc_connection_interface_addressing_get_contacts_by_vcard_field_impl) (TpSvcConnectionInterfaceAddressing *self,
+    const gchar *in_Field,
+    const gchar **in_Addresses,
+    const gchar **in_Interfaces,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_addressing_implement_get_contacts_by_vcard_field (TpSvcConnectionInterfaceAddressingClass *klass, tp_svc_connection_interface_addressing_get_contacts_by_vcard_field_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_addressing_return_from_get_contacts_by_vcard_field (DBusGMethodInvocation *context,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes);
+static inline void
+tp_svc_connection_interface_addressing_return_from_get_contacts_by_vcard_field (DBusGMethodInvocation *context,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes)
+{
+  dbus_g_method_return (context,
+      out_Requested,
+      out_Attributes);
+}
+
+typedef void (*tp_svc_connection_interface_addressing_get_contacts_by_uri_impl) (TpSvcConnectionInterfaceAddressing *self,
+    const gchar **in_URIs,
+    const gchar **in_Interfaces,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_addressing_implement_get_contacts_by_uri (TpSvcConnectionInterfaceAddressingClass *klass, tp_svc_connection_interface_addressing_get_contacts_by_uri_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_addressing_return_from_get_contacts_by_uri (DBusGMethodInvocation *context,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes);
+static inline void
+tp_svc_connection_interface_addressing_return_from_get_contacts_by_uri (DBusGMethodInvocation *context,
+    GHashTable *out_Requested,
+    GHashTable *out_Attributes)
+{
+  dbus_g_method_return (context,
+      out_Requested,
+      out_Attributes);
+}
+
+
 typedef struct _TpSvcConnectionInterfaceAliasing TpSvcConnectionInterfaceAliasing;
 
 typedef struct _TpSvcConnectionInterfaceAliasingClass TpSvcConnectionInterfaceAliasingClass;
@@ -1014,6 +1071,18 @@ tp_svc_connection_interface_contact_list_return_from_unpublish (DBusGMethodInvoc
   dbus_g_method_return (context);
 }
 
+typedef void (*tp_svc_connection_interface_contact_list_download_impl) (TpSvcConnectionInterfaceContactList *self,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_list_implement_download (TpSvcConnectionInterfaceContactListClass *klass, tp_svc_connection_interface_contact_list_download_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_list_return_from_download (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_list_return_from_download (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
 void tp_svc_connection_interface_contact_list_emit_contact_list_state_changed (gpointer instance,
     guint arg_Contact_List_State);
 void tp_svc_connection_interface_contact_list_emit_contacts_changed_with_id (gpointer instance,
