@@ -72,6 +72,22 @@ tp_svc_media_stream_handler_return_from_new_active_candidate_pair (DBusGMethodIn
   dbus_g_method_return (context);
 }
 
+typedef void (*tp_svc_media_stream_handler_new_active_transport_pair_impl) (TpSvcMediaStreamHandler *self,
+    const gchar *in_Native_Candidate_ID,
+    const GValueArray *in_Native_Transport,
+    const gchar *in_Remote_Candidate_ID,
+    const GValueArray *in_Remote_Transport,
+    DBusGMethodInvocation *context);
+void tp_svc_media_stream_handler_implement_new_active_transport_pair (TpSvcMediaStreamHandlerClass *klass, tp_svc_media_stream_handler_new_active_transport_pair_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_media_stream_handler_return_from_new_active_transport_pair (DBusGMethodInvocation *context);
+static inline void
+tp_svc_media_stream_handler_return_from_new_active_transport_pair (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
 typedef void (*tp_svc_media_stream_handler_new_native_candidate_impl) (TpSvcMediaStreamHandler *self,
     const gchar *in_Candidate_ID,
     const GPtrArray *in_Transports,
@@ -176,6 +192,32 @@ tp_svc_media_stream_handler_return_from_unhold_failure (DBusGMethodInvocation *c
   dbus_g_method_return (context);
 }
 
+typedef void (*tp_svc_media_stream_handler_supported_feedback_messages_impl) (TpSvcMediaStreamHandler *self,
+    GHashTable *in_Messages,
+    DBusGMethodInvocation *context);
+void tp_svc_media_stream_handler_implement_supported_feedback_messages (TpSvcMediaStreamHandlerClass *klass, tp_svc_media_stream_handler_supported_feedback_messages_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_media_stream_handler_return_from_supported_feedback_messages (DBusGMethodInvocation *context);
+static inline void
+tp_svc_media_stream_handler_return_from_supported_feedback_messages (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_media_stream_handler_supported_header_extensions_impl) (TpSvcMediaStreamHandler *self,
+    const GPtrArray *in_Header_Extensions,
+    DBusGMethodInvocation *context);
+void tp_svc_media_stream_handler_implement_supported_header_extensions (TpSvcMediaStreamHandlerClass *klass, tp_svc_media_stream_handler_supported_header_extensions_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_media_stream_handler_return_from_supported_header_extensions (DBusGMethodInvocation *context);
+static inline void
+tp_svc_media_stream_handler_return_from_supported_header_extensions (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
 void tp_svc_media_stream_handler_emit_add_remote_candidate (gpointer instance,
     const gchar *arg_Candidate_ID,
     const GPtrArray *arg_Transports);
@@ -195,9 +237,18 @@ void tp_svc_media_stream_handler_emit_set_stream_sending (gpointer instance,
     gboolean arg_Sending);
 void tp_svc_media_stream_handler_emit_start_telephony_event (gpointer instance,
     guchar arg_Event);
+void tp_svc_media_stream_handler_emit_start_named_telephony_event (gpointer instance,
+    guchar arg_Event,
+    guint arg_Codec_ID);
+void tp_svc_media_stream_handler_emit_start_sound_telephony_event (gpointer instance,
+    guchar arg_Event);
 void tp_svc_media_stream_handler_emit_stop_telephony_event (gpointer instance);
 void tp_svc_media_stream_handler_emit_set_stream_held (gpointer instance,
     gboolean arg_Held);
+void tp_svc_media_stream_handler_emit_set_remote_feedback_messages (gpointer instance,
+    GHashTable *arg_Messages);
+void tp_svc_media_stream_handler_emit_set_remote_header_extensions (gpointer instance,
+    const GPtrArray *arg_Header_Extensions);
 
 
 G_END_DECLS
